==> 0.0.2.tar.gz: lib/src/easy_church_json.dart <==
part of easy_church_json;

/// EasyChurchJsonClass
///
/// This class is a factory so it has only one instance.
class EasyChurchJson {
  /// General instance.
  static EasyChurchJson _instance = new EasyChurchJson._internal();

  /// Constructor.
  factory EasyChurchJson() {
    return _instance;
  }

  /// Internal constructor.
  EasyChurchJson._internal();

  ///Get all churches
  ///
  /// Gets a list of churches
  Future<List<SingleChurch>> getAllChurches() async {
    List<SingleChurch> list = [];
    try {
      var response =
          await http.get("https://easy-church-api.herokuapp.com/getChurches");

      if (response.statusCode == 200) {
        var j = json.decode(response.body);
        for (int i = 0; i < j.length; i++) {
          SingleChurch singleChurch = SingleChurch.fromJson(j[i]);
          list.add(singleChurch);

          //Confirm fields
//          if (singleChurch.id != null) {
//            print("Id: ${singleChurch.id}");
//          }
//          if (singleChurch.name != null) {
//            print("Name: ${singleChurch.name}");
//          }
//          if (singleChurch.bio != null) {
//            print("Bio: ${singleChurch.bio}");
//          }
//          if (singleChurch.elderId != null) {
//            print("Elder id: ${singleChurch.elderId}");
//          }
//          if (singleChurch.createdAt != null) {
//            print("Created at: ${singleChurch.createdAt}");
//          }
//          if (singleChurch.members.length > 0) {
//            print("Members: ${singleChurch.members.toString()}");
//          }
        }

        return list;
      } else {
        print("Failed to get Info");
        return null;
      }
    } on http.ClientException catch (e) {
      print(e.toString());
      return null;
    }
  }

  ///Get all notifications of a church -> ID
  Future<List<SingleNotification>> getNotifications(String id) async {
    List<SingleNotification> list = [];
    try {
      var response = await http
          .get("https://easy-church-api.herokuapp.com/getNotifications/$id");

      if (response.statusCode == 200) {
        var j = json.decode(response.body);
        for (int i = 0; i < j.length; i++) {
          SingleNotification singleNotification =
              SingleNotification.fromJson(j[i]);
          list.add(singleNotification);

          //Confirm fields
//          if (singleNotification.id != null) {
//            print("Id: ${singleNotification.id}");
//          }
//          if (singleNotification.createdAt != null) {
//            print("Created at: ${singleNotification.createdAt}");
//          }
//          if (singleNotification.title != null) {
//            print("Title: ${singleNotification.title}");
//          }
//          if (singleNotification.description != null) {
//            print("Description: ${singleNotification.description}");
//          }
//          if (singleNotification.churchId != null) {
//            print("Church id: ${singleNotification.churchId}");
//          }
        }

        return list;
      } else {
        print("Failed to get Info");
        return null;
      }
    } on http.ClientException catch (e) {
      print(e.toString());
      return null;
    }
  }

  ///Get all events of a church -> ID
  Future<List<SingleEvent>> getEvents(String id) async {
    List<SingleEvent> list = [];
    try {
      var response =
          await http.get("https://easy-church-api.herokuapp.com/getEvents/$id");

      if (response.statusCode == 200) {
        var j = json.decode(response.body);
        for (int i = 0; i < j.length; i++) {
          SingleEvent singleEvent = SingleEvent.fromJson(j[i]);
          list.add(singleEvent);

          //Confirm fields
//          if (singleEvent.id != null) {
//            print("Id: ${singleEvent.id}");
//          }
//          if (singleEvent.title != null) {
//            print("Title: ${singleEvent.title}");
//          }
//          if (singleEvent.description != null) {
//            print("Description: ${singleEvent.description}");
//          }
//          if (singleEvent.churchId != null) {
//            print("Church id: ${singleEvent.churchId}");
//          }
//          if (singleEvent.dueDate != null) {
//            print("Due date: ${singleEvent.dueDate}");
//          }
//          if (singleEvent.createdAt != null) {
//            print("Created at: ${singleEvent.createdAt}");
//          }
        }

        return list;
      } else {
        print("Failed to get Info");
        return null;
      }
    } on http.ClientException catch (e) {
      print(e.toString());
      return null;
    }
  }

  ///Subscribe to a church
  ///
  /// Requires an Id of a church and the phones IMEI number
  Future<void> followChurch(String churchId, String IMEI) async {
    try {
      var response = await http.get(
          "https://easy-church-api.herokuapp.com/subChurch/$churchId/$IMEI");

      if (response.statusCode == 200) {
        String resp = response.body;

        if (resp == "Save successful") {
          //User has been successfully subscribed
          print("User successfully subscribed to church");
        } else {
          //Failed
        }
      } else {
        print("Failed tro get Info");
      }
    } on http.ClientException catch (e) {
      print(e.toString());
      return null;
    }
  }

  ///Get a church which the user is subscribed to
  ///
  /// Requires the phones IMEI number
  Future<List<SingleChurch>> getChurch(String IMEI) async {
    List<SingleChurch> list = [];

    try {
      var response = await http
          .get("https://easy-church-api.herokuapp.com/getChurch/$IMEI");

      if (response.statusCode == 200) {
        var j = json.decode(response.body);
        for (int i = 0; i < j.length; i++) {
          SingleChurch singleChurch = SingleChurch.fromJson(j[i]);
          list.add(singleChurch);

          //Confirm fields
          if (singleChurch.id != null) {
            print("Id: ${singleChurch.id}");
          }
          if (singleChurch.name != null) {
            print("Name: ${singleChurch.name}");
          }
          if (singleChurch.bio != null) {
            print("Bio: ${singleChurch.bio}");
          }
          if (singleChurch.elderId != null) {
            print("Elder id: ${singleChurch.elderId}");
          }
          if (singleChurch.createdAt != null) {
            print("Created at: ${singleChurch.createdAt}");
          }
          if (singleChurch.members.length > 0) {
            print("Members: ${singleChurch.members.toString()}");
          }
        }

        return list;
      } else {
        print("Failed to get Info");
        return null;
      }
    } on http.ClientException catch (e) {
      print(e.toString());
      return null;
    }
  }
}

==> 0.0.3.tar.gz: lib/src/easy_church_json.dart <==
part of easy_church_json;

/// EasyChurchJsonClass
///
/// This class is a factory so it has only one instance.
class EasyChurchJson {
  /// General instance.
  static EasyChurchJson _instance = new EasyChurchJson._internal();

  /// Constructor.
  factory EasyChurchJson() {
    return _instance;
  }

  /// Internal constructor.
  EasyChurchJson._internal();

  ///Get all churches
  ///
  /// Gets a list of churches
  Future<List<SingleChurch>> getAllChurches() async {
    List<SingleChurch> list = [];
    try {
      var response =
          await http.get("https://easy-church-api.herokuapp.com/getChurches");

      if (response.statusCode == 200) {
        var j = json.decode(response.body);
        for (int i = 0; i < j.length; i++) {
          SingleChurch singleChurch = SingleChurch.fromJson(j[i]);
          list.add(singleChurch);

          //Confirm fields
//          if (singleChurch.id != null) {
//            print("Id: ${singleChurch.id}");
//          }
//          if (singleChurch.name != null) {
//            print("Name: ${singleChurch.name}");
//          }
//          if (singleChurch.bio != null) {
//            print("Bio: ${singleChurch.bio}");
//          }
//          if (singleChurch.elderId != null) {
//            print("Elder id: ${singleChurch.elderId}");
//          }
//          if (singleChurch.createdAt != null) {
//            print("Created at: ${singleChurch.createdAt}");
//          }
//          if (singleChurch.members.length > 0) {
//            print("Members: ${singleChurch.members.toString()}");
//          }
        }

        return list;
      } else {
        print("Failed to get Info");
        return null;
      }
    } on http.ClientException catch (e) {
      print(e.toString());
      return null;
    }
  }

  ///Get all notifications of a church -> ID
  Future<List<SingleNotification>> getNotifications(String id) async {
    List<SingleNotification> list = [];
    try {
      var response = await http
          .get("https://easy-church-api.herokuapp.com/getNotifications/$id");

      if (response.statusCode == 200) {
        var j = json.decode(response.body);
        for (int i = 0; i < j.length; i++) {
          SingleNotification singleNotification =
              SingleNotification.fromJson(j[i]);
          list.add(singleNotification);

          //Confirm fields
//          if (singleNotification.id != null) {
//            print("Id: ${singleNotification.id}");
//          }
//          if (singleNotification.createdAt != null) {
//            print("Created at: ${singleNotification.createdAt}");
//          }
//          if (singleNotification.title != null) {
//            print("Title: ${singleNotification.title}");
//          }
//          if (singleNotification.description != null) {
//            print("Description: ${singleNotification.description}");
//          }
//          if (singleNotification.churchId != null) {
//            print("Church id: ${singleNotification.churchId}");
//          }
        }

        return list;
      } else {
        print("Failed to get Info");
        return null;
      }
    } on http.ClientException catch (e) {
      print(e.toString());
      return null;
    }
  }

  ///Get all events of a church -> ID
  Future<List<SingleEvent>> getEvents(String id) async {
    List<SingleEvent> list = [];
    try {
      var response =
          await http.get("https://easy-church-api.herokuapp.com/getEvents/$id");

      if (response.statusCode == 200) {
        var j = json.decode(response.body);
        for (int i = 0; i < j.length; i++) {
          SingleEvent singleEvent = SingleEvent.fromJson(j[i]);
          list.add(singleEvent);

          //Confirm fields
//          if (singleEvent.id != null) {
//            print("Id: ${singleEvent.id}");
//          }
//          if (singleEvent.title != null) {
//            print("Title: ${singleEvent.title}");
//          }
//          if (singleEvent.description != null) {
//            print("Description: ${singleEvent.description}");
//          }
//          if (singleEvent.churchId != null) {
//            print("Church id: ${singleEvent.churchId}");
//          }
//          if (singleEvent.dueDate != null) {
//            print("Due date: ${singleEvent.dueDate}");
//          }
//          if (singleEvent.createdAt != null) {
//            print("Created at: ${singleEvent.createdAt}");
//          }
        }

        return list;
      } else {
        print("Failed to get Info");
        return null;
      }
    } on http.ClientException catch (e) {
      print(e.toString());
      return null;
    }
  }

  ///Subscribe to a church
  ///
  /// Requires an Id of a church and the phones IMEI number
  Future<String> followChurch(String churchId, String IMEI) async {
    try {
      var response = await http.get(
          "https://easy-church-api.herokuapp.com/subChurch/$churchId/$IMEI");

      if (response.statusCode == 200) {
        String resp = response.body;

        if (resp == "Save successful") {
          //User has been successfully subscribed
          return "Success";
        } else {
          //Failed
          return "Failed";
        }
      } else {
        return "Network Fail";
      }
    } on http.ClientException catch (e) {
      print(e.toString());
      return null;
    }
  }

  ///Get a church which the user is subscribed to
  ///
  /// Requires the phones IMEI number
  Future<List<SingleChurch>> getChurch(String IMEI) async {
    List<SingleChurch> list = [];

    try {
      var response = await http
          .get("https://easy-church-api.herokuapp.com/getChurch/$IMEI");

      if (response.statusCode == 200) {
        var j = json.decode(response.body);
        for (int i = 0; i < j.length; i++) {
          SingleChurch singleChurch = SingleChurch.fromJson(j[i]);
          list.add(singleChurch);

          //Confirm fields
          if (singleChurch.id != null) {
            print("Id: ${singleChurch.id}");
          }
          if (singleChurch.name != null) {
            print("Name: ${singleChurch.name}");
          }
          if (singleChurch.bio != null) {
            print("Bio: ${singleChurch.bio}");
          }
          if (singleChurch.elderId != null) {
            print("Elder id: ${singleChurch.elderId}");
          }
          if (singleChurch.createdAt != null) {
            print("Created at: ${singleChurch.createdAt}");
          }
          if (singleChurch.members.length > 0) {
            print("Members: ${singleChurch.members.toString()}");
          }
        }

        return list;
      } else {
        print("Failed to get Info");
        return null;
      }
    } on http.ClientException catch (e) {
      print(e.toString());
      return null;
    }
  }
}
